@@ -800,132 +800,6 @@ GetNConstraint.discreteClass<-function(object)
     return(object$nStates)
 }
 
-logForwardBackward<-function(HMM, obs)
-{   if ( ( class(HMM) != "HMMFitClass" ) && (class(HMM) != "HMMClass") )
-        stop("class(HMM) must be 'HMMClass' or 'HMMFitClass'\n")
-    if (class(HMM) == "HMMFitClass")
-        HMM <- HMM$HMM
-
-    if (is.data.frame(obs))
-    {   dimObs <- dim(obs)[2]
-        if (dimObs == 1)
-            obs <- obs[,1]
-        else
-            obs <- as.matrix(obs[,1:dimObs])
-    }
-
-    HMM <- setStorageMode(HMM)
-    maListe <- TransformeListe(HMM$distribution, obs)
-    Res1 <- .Call("RLogforwardbackward", HMM, maListe$Zt)
-    names(Res1) <- c("LLH")
-    if (!is.list(obs))
-    {   Res1$LLH <- Res1$LLH[[1]]
-    }
-     return(Res1)
-}
-
-NumLLH <- function(Teta, HMM, obs, nSample)
-{
-    HMM1<-SetVectAllParam(HMM, Teta)
-    LLH <- sumList(logForwardBackward( HMM1, obs)$LLH, nSample)
-    return(-LLH)
-}
-
-NumLLH1 <- function(Teta, HMM, obs, nSample)
-{
-    HMM1<-SetVectParam(HMM, Teta)
-    LLH <- sumList(logForwardBackward( HMM1, obs)$LLH, nSample)
-    return(-LLH)
-}
-
-optimHessian <- function(par, fn, ...)
-{
-    fn1 <- function(par) fn(par, ...)
-    con <- list(trace = 0, fnscale = 1, parscale = rep.int(1,
-        length(par)), ndeps = rep.int(0.001, length(par)), maxit = 100L,
-        abstol = -Inf, reltol = sqrt(.Machine$double.eps), alpha = 1,
-        beta = 0.5, gamma = 2, REPORT = 10, type = 1, lmm = 5,
-        factr = 1e+07, pgtol = 0, tmax = 10, temp = 10)
-    hess <- try(.Internal(optimhess(par, fn1, NULL, con)), silent=TRUE)
-    nParam <- length(par)
-    if (class(hess) == "try-error")
-    {   warning("non-finite finite-difference value while computing the Hessian matrix ...")
-        hess <- matrix(0, nrow=nParam, ncol=nParam)
-    }
-    else
-    {   hess <- 0.5 * (hess + t(hess))
-    }
-
-    return(hess)
-}
-
-
-nlmeHessian <- function(par, fn, ...)
-{
-    fn1 <- function(par) fn(par, ...)
-    hess <- try(fdHess(par, fn1)$Hessian, silent=TRUE)
-    nParam <- length(par)
-    if (class(hess) == "try-error")
-    {   warning("non-finite finite-difference value while computing the Hessian matrix ...")
-        hess <- matrix(0, nrow=nParam, ncol=nParam)
-    }
-    return(hess)
-}
-
-ComputeHessian <- function(HMM, obs, asymptMethod)
-{
-    if (is.list(obs))
-    {   nSample <- length(obs)
-    }
-    else
-    {   nSample <- 1
-    }
-
-    listeParam <- GetNAllParam(HMM)
-    Teta0 <- GetVectAllParam(HMM)
-
-    if (asymptMethod == 'nlme')
-        Hess<- try(
-                     nlmeHessian(par=Teta0, fn=NumLLH, HMM=HMM, obs=obs, nSample=nSample)
-                )
-    else
-        Hess<- try(
-                    optimHessian(par=Teta0, fn=NumLLH, HMM=HMM, obs=obs, nSample=nSample)
-                )
-
-    if (class(Hess) == "try-error")
-       return(matrix(NaN, nrow=listeParam$nParam, ncol=listeParam$nParam))
-    else
-        return(Hess)
-}
-
-ComputeHessian1 <- function(HMM, obs, asymptMethod)
-{
-    if (is.list(obs))
-    {   nSample <- length(obs)
-    }
-    else
-    {   nSample <- 1
-    }
-
-    listeParam <- GetNParam(HMM)
-    Teta0 <- GetVectParam(HMM)
-
-    if (asymptMethod == 'nlme')
-        Hess<- try(
-                     nlmeHessian(par=Teta0, fn=NumLLH1, HMM=HMM, obs=obs, nSample=nSample)
-                )
-    else
-        Hess<- try(
-                    optimHessian(par=Teta0, fn=NumLLH1, HMM=HMM, obs=obs, nSample=nSample)
-                )
-
-    if (class(Hess) == "try-error")
-       return(matrix(NaN, nrow=listeParam$nParam, ncol=listeParam$nParam))
-    else
-        return(Hess)
-}
-
 computeScoreAndInformation <- function(HMM, obs)
 {
     if ( ( class(HMM) != "HMMFitClass" ) && (class(HMM) != "HMMClass") )
@@ -977,69 +851,6 @@ asymptoticCov <- function(HMM, obs)
     return(Res)
 }
 
-#asymptoticCovMat <- function(HMM, obs, asymptMethod=c('nlme', 'optim'))
-#{
-#    if ( ( class(HMM) != "HMMFitClass" ) && (class(HMM) != "HMMClass") )
-#        stop("class(HMM) must be 'HMMClass' or 'HMMFitClass'\n")
-#    if (class(HMM) == "HMMFitClass")
-#        HMM <- HMM$HMM
-#   Hh <- ComputeHessian(HMM, obs, asymptMethod[1])
-#    nParam <- dim(Hh)[1]
-#    K <- GradConstraint(HMM)
-#    Dh <- Hh + t(K) %*% K
-#    Dm1 <- try(solve(Dh), silent=TRUE)
-#    if (class(Dm1)=="try-error")
-#    {   asymptMatCov <- matrix(NaN, ncol=nParam, nrow=nParam)
-#        colnames(asymptMatCov) <- rownames(asymptMatCov) <- NomsParamHMM(HMM)
-#        warning("Hessian matrix is not inversible")
-#        return(asymptMatCov)
-#    }
-#    Aux <- K %*% Dm1 %*% t(K)
-#    Auxm1 <- try(solve(Aux), silent=TRUE)
-#    if (class(Auxm1)=="try-error")
-#    {   asymptMatCov <- matrix(NaN, ncol=nParam, nrow=nParam)
-#        colnames(asymptMatCov) <- rownames(asymptMatCov) <- NomsParamHMM(HMM)
-#        warning("Hessian matrix is not inversible")
-#        return(asymptMatCov)
-#    }
-#    asymptMatCov <- Dm1 - Dm1 %*% t(K) %*% Auxm1 %*% K %*% Dm1
-#    if (is.list(obs))
-#    {   nTot <- length(obs[[1]])
-#        nSample <- length(obs)
-#        if (nSample > 1)
-#        {   for (j in 2:nSample)
-#                nTot <- nTot + length(obs[[j]])
-#        }
-#    }
-#    else
-#        nTot <- length(obs)
-#
-#    colnames(asymptMatCov) <- rownames(asymptMatCov) <- NomsParamHMM(HMM)
-#    return(asymptMatCov)
-#}
-
-#asymptoticSimCovMat <- function(HMM, obs, nSimul, verbose=FALSE, oldCovMat=NULL, oldNSimul=0)
-#{
-#    if ( ( class(HMM) != "HMMFitClass" ) && (class(HMM) != "HMMClass") )
-#        stop("class(HMM) must be 'HMMClass' or 'HMMFitClass'\n")
-#    if (class(HMM) == "HMMFitClass")
-#        HMM <- HMM$HMM
-#
-#    if (is.null(oldCovMat))
-#    {
-#        Res <- asymptoticIterSimCovMat(HMM, obs, nSimul, verbose)
-#    }
-#    else
-#    {   Teta <- GetVectAllParam(HMM)
-#        esp2Mat <- Teta %*% t(Teta)
-#        espVect <- Teta
-#        nSimul <- oldNSimul
-#        old <- list(cov=oldCovMat, esp2Mat=esp2Mat, mean = espVect, nSimul=oldNSimul)
-#        Res <- asymptoticIterSimCovMat(HMM, obs, nSimul, verbose, old)
-#    }
-#    warning("asymtoticSimCovMat is deprecated. Use asymptoticIterSimCovMat")
-#    return(Res$cov)
-# }
 
 asymptoticIterSimCovMat <- function(HMM, obs, nSimul, verbose=FALSE, oldCovMat=NULL)
 {
@@ -1098,46 +909,6 @@ asymptoticIterSimCovMat <- function(HMM, obs, nSimul, verbose=FALSE, oldCovMat=N
 }
 
 
-#asymptoticCovMat <- function(HMM, obs, asymptMethod=c('nlme', 'optim'))
-#{
-#    if ( ( class(HMM) != "HMMFitClass" ) && (class(HMM) != "HMMClass") )
-#        stop("class(HMM) must be 'HMMClass' or 'HMMFitClass'\n")
-#    if (class(HMM) == "HMMFitClass")
-#        HMM <- HMM$HMM
-#    Hh <- ComputeHessian(HMM, obs, asymptMethod[1])
-#    nParam <- dim(Hh)[1]
-#    K <- GradConstraint(HMM)
-#    Dh <- Hh + t(K) %*% K
-#    Dm1 <- try(solve(Dh), silent=TRUE)
-#    if (class(Dm1)=="try-error")
-#    {   asymptMatCov <- matrix(NaN, ncol=nParam, nrow=nParam)
-#        colnames(asymptMatCov) <- rownames(asymptMatCov) <- NomsParamHMM(HMM)
-#        warning("Hessian matrix is not inversible")
-#        return(asymptMatCov)
-#    }
-#    Aux <- K %*% Dm1 %*% t(K)
-#    Auxm1 <- try(solve(Aux), silent=TRUE)
-#    if (class(Auxm1)=="try-error")
-#    {   asymptMatCov <- matrix(NaN, ncol=nParam, nrow=nParam)
-#        colnames(asymptMatCov) <- rownames(asymptMatCov) <- NomsParamHMM(HMM)
-#        warning("Hessian matrix is not inversible")
-#        return(asymptMatCov)
-#    }
-#    asymptMatCov <- Dm1 - Dm1 %*% t(K) %*% Auxm1 %*% K %*% Dm1
-#    if (is.list(obs))
-#    {   nTot <- length(obs[[1]])
-#        nSample <- length(obs)
-#        if (nSample > 1)
-#        {   for (j in 2:nSample)
-#                nTot <- nTot + length(obs[[j]])
-#        }
-#    }
-#    else
-#        nTot <- length(obs)
-#
-#    colnames(asymptMatCov) <- rownames(asymptMatCov) <- NomsParamHMM(HMM)
-#    return(asymptMatCov)
-#}
 
 setAsymptoticCovMat<-function(HMMFit, asymptCovMat)
 {
