@@ -23,17 +23,21 @@ class cMultivariateNormal : public cDistribution
                 cDMatrix*      mCov    ;
         public :
                 cMultivariateNormal(uint theNClass = 0, uint theDimObs = 1) ;
-                virtual ~cMultivariateNormal() ;
+                cMultivariateNormal(cDistribution& theSrc) ;
+				virtual ~cMultivariateNormal() ;
                 void ComputeCondProba(cDVector* theY, uint theNSample, cDMatrix* theCondProba) ;
-                void UpdateParameters(cInParam& theInParam, cBaumWelch& theBaumWelch, cDMatrix* theCondProba=NULL) ;
+                void ComputeDerivative(cDVector& theY, cDVector** theGrad, cDMatrix** theHess) ;
+				void ComputeCov(cDMatrix& theCov) ;
+				cDVector GetDistrNumParam(const cDVector& theNumDistrParam, uint& theNextInd) ;
+				void UpdateParameters(cInParam& theInParam, cBaumWelch& theBaumWelch, cDMatrix* theCondProba=NULL) ;
                 void InitParameters(cBaumWelchInParam &theInParam) ;
                 void Print() ;
                 void GetParam(uint theDeb, cDVector& theParam) ;
                 void SetParam(uint theDeb, cDVector& theParam) ;
                 uint GetDimObs() ;
                 void CopyDistr(cDistribution* theSrc) ;
-                uint GetNParam(void){ return mMean[0].mSize + mMean[0].mSize * mMean[0].mSize ; }
-                uint GetNFreeParam(void){ return mMean[0].mSize + mMean[0].mSize * (mMean[0].mSize + 1)/2; }
+                uint GetNParam(void){ return mMean[0].mSize + mMean[0].mSize * (mMean[0].mSize + 1)/2 ; }
+                uint GetNFreeParam(void){ return mMean[0].mSize + mMean[0].mSize * (mMean[0].mSize + 1)/2 ; }
 
 } ;
 #endif //_CMULTIVARIATENORMAL_H_
